@@ -1,10 +1,10 @@
 #! /usr/bin/perl
 
-# $Id: lamdaemon.pl,v 1.56 2010/08/30 20:01:14 gruberroland Exp $
+# $Id: lamdaemon.pl,v 1.60 2011/02/12 15:30:22 gruberroland Exp $
 #
 #  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 #  Copyright (C) 2003 - 2006  Tilo Lutz
-#  Copyright (C) 2006 - 2010  Roland Gruber
+#  Copyright (C) 2006 - 2011  Roland Gruber
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@
 
 use Sys::Syslog;
 
+# Defines the protocol version of the lamdaemon script.
+# This will only be changed when additional commands are added etc.
+my $LAMDAEMON_PROTOCOL_VERSION = 1;
+
 my $SPLIT_DELIMITER = "###x##y##x###";
 
 # set a known path
@@ -76,14 +80,14 @@ sub get_fs { # Load mountpoints from mtab if enabled quotas
 	Quota::endmntent();
 	my $j=0; my $k=0; $i=0;
 	while ($args[$i][0]) {
-		if ( $args[$i][3] =~ m/usrquota/ ) {
+		if ( $args[$i][3] =~ m/usr[j]?quota/ ) {
 			$quota_usr[$j][0] = $args[$i][0];
 			$quota_usr[$j][1] = $args[$i][1];
 			$quota_usr[$j][2] = $args[$i][2];
 			$quota_usr[$j][3] = $args[$i][3];
 			$j++;
 			}
-		if ( $args[$i][3] =~ m/grpquota/ ) {
+		if ( $args[$i][3] =~ m/grp[j]?quota/ ) {
 			$quota_grp[$k][0] = $args[$i][0];
 			$quota_grp[$k][1] = $args[$i][1];
 			$quota_grp[$k][2] = $args[$i][2];
@@ -134,8 +138,17 @@ print "$return\n";
 # Runs tests to check the environment
 #
 sub runTest {
+	# protocol version check
+	if ($vals[2] eq 'version') {
+		if ($vals[3] eq $LAMDAEMON_PROTOCOL_VERSION) {
+			$return = "INFO,Version check ok";
+		}
+		else {
+			$return = "ERROR,Version check failed. Please upgrade the lamdaemon script to the same version as your main LAM installation.";
+		}
+	}
 	# basic test
-	if ($vals[2] eq 'basic') {
+	elsif ($vals[2] eq 'basic') {
 		$return = "INFO,Basic test ok";
 	}
 	# quota test
@@ -165,6 +178,9 @@ sub runTest {
 			}
 		}
 	}
+	else {
+		$return = "ERROR,Unknown test: $vals[2]";
+	}
 }
 
 #
@@ -240,8 +256,8 @@ sub removeHomedir {
 			logMessage(LOG_INFO, "Home directory removed (" . $vals[3] . ")");
 		}
 		else {
-			$return = "ERROR,Lamdaemon ($hostname),Home directory not owned by $vals[3].";
-			logMessage(LOG_ERR, "Home directory owned by wrong user (" . $vals[3] . ")");
+			$return = "ERROR,Lamdaemon ($hostname),Home directory not owned by $vals[4].";
+			logMessage(LOG_ERR, "Home directory owned by wrong user (" . $vals[4] . ")");
 		}
 	}
 	else {
