@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: moduleSettings.php,v 1.10 2010/09/13 20:05:58 gruberroland Exp $
+$Id: moduleSettings.php,v 1.14 2011/01/08 19:44:08 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2009 - 2010  Roland Gruber
+  Copyright (C) 2009 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -137,13 +137,6 @@ for ($i = 0; $i < sizeof($errorsToDisplay); $i++) call_user_func_array('StatusMe
 
 echo ("<form action=\"moduleSettings.php\" method=\"post\">\n");
 
-echo '<div style="text-align: right;">';
-echo "<button id=\"saveButton\" name=\"saveSettings\" type=\"submit\">" . _('Save') . "</button>";
-echo "&nbsp;";
-echo "<button id=\"cancelButton\" name=\"cancelSettings\" type=\"submit\">" . _('Cancel') . "</button>";
-echo "<br><br>\n";
-echo '</div>';
-
 // hidden submit buttons which are clicked by tabs
 echo "<div style=\"display: none;\">\n";
 	echo "<input name=\"generalSettingsButton\" type=\"submit\" value=\" \">";
@@ -156,15 +149,15 @@ echo "</div>\n";
 echo '<div class="ui-tabs ui-widget ui-widget-content ui-corner-all">';
 
 echo '<ul class="ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all">';
-echo '<li id="generalSettingsButton" class="ui-state-default ui-corner-top">';
+echo '<li id="generalSettingsButton" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'generalSettingsButton\')[0].click();"><img src="../../graphics/tools.png" alt=""> ';
 	echo _('General settings') . '</a>';
 echo '</li>';
-echo '<li id="edittypes" class="ui-state-default ui-corner-top">';
+echo '<li id="edittypes" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'edittypes\')[0].click();"><img src="../../graphics/gear.png" alt=""> ';
 	echo _('Account types') . '</a>';
 echo '</li>';
-echo '<li id="editmodules" class="ui-state-default ui-corner-top">';
+echo '<li id="editmodules" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'editmodules\')[0].click();"><img src="../../graphics/modules.png" alt=""> ';
 	echo _('Modules') . '</a>';
 echo '</li>';
@@ -180,20 +173,11 @@ echo '</ul>';
 jQuery(document).ready(function() {
 	jQuery('#moduleSettings').addClass('ui-tabs-selected');
 	jQuery('#moduleSettings').addClass('ui-state-active');
-	jQuery('#saveButton').button({
-        icons: {
-      	  primary: 'saveButton'
-    	}
-	});
-	jQuery('#cancelButton').button({
-        icons: {
-    	  primary: 'cancelButton'
-  	}
-	});
+	jQuery('#moduleSettings').addClass('userlist-bright');
 });
 </script>
 
-<div class="ui-tabs-panel ui-widget-content ui-corner-bottom">
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom userlist-bright">
 <?php
 
 
@@ -219,15 +203,15 @@ $modules = array_keys($options);
 $_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
 	if (sizeof($options[$modules[$i]]) < 1) continue;
-	echo "<fieldset>\n";
+	echo "<fieldset class=\"ui-corner-all useredit\">\n";
 	$icon = '';
 	$module = new $modules[$i]('none');
 	$iconImage = $module->getIcon();
 	if ($iconImage != null) {
 		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
 	}
-	echo "<legend>$icon<b>" . getModuleAlias($modules[$i], "none") . "</b></legend><br>\n";
-	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, 'config');
+	echo "<legend>$icon<b>" . getModuleAlias($modules[$i], "none") . "</b></legend>\n";
+	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, 'user');
 	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
 	echo "</fieldset>\n";
 	echo "<br>";
@@ -235,7 +219,20 @@ for ($i = 0; $i < sizeof($modules); $i++) {
 
 echo "<input type=\"hidden\" name=\"postAvailable\" value=\"yes\">\n";
 
-echo ("</div></div></form>\n");
+echo "</div></div>";
+
+$buttonContainer = new htmlTable();
+$buttonContainer->addElement(new htmlSpacer(null, '10px'), true);
+$saveButton = new htmlButton('saveSettings', _('Save'));
+$saveButton->setIconClass('saveButton');
+$buttonContainer->addElement($saveButton);
+$cancelButton = new htmlButton('cancelSettings', _('Cancel'));
+$cancelButton->setIconClass('cancelButton');
+$buttonContainer->addElement($cancelButton, true);
+$buttonContainer->addElement(new htmlSpacer(null, '10px'), true);
+parseHtml(null, $buttonContainer, array(), false, $tabindex, 'user');
+
+echo "</form>\n";
 echo "</body>\n";
 echo "</html>\n";
 
