@@ -1,10 +1,10 @@
 <?php
 /*
-	$Id: delete.php,v 1.81 2010/10/12 17:49:18 gruberroland Exp $
+	$Id: delete.php,v 1.84 2011/02/26 13:14:10 gruberroland Exp $
 
 	This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 	Copyright (C) 2003 - 2006  Tilo Lutz
-	Copyright (C) 2007 - 2010  Roland Gruber
+	Copyright (C) 2007 - 2011  Roland Gruber
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -62,9 +62,6 @@ if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 // Set correct language, codepages, ....
 setlanguage();
 
-if (!isset($_SESSION['cache'])) {
-	$_SESSION['cache'] = new cache();
-}
 if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	// Create account list
 	foreach ($_SESSION['delete_dn'] as $dn) {
@@ -126,6 +123,10 @@ if (isset($_POST['cancel'])) {
 	if (isset($_SESSION['delete_dn'])) unset($_SESSION['delete_dn']);
 	metaRefresh("lists/list.php?type=" . $_POST['type']);
 }
+elseif (isset($_POST['cancelAllOk'])) {
+	if (isset($_SESSION['delete_dn'])) unset($_SESSION['delete_dn']);
+	metaRefresh("lists/list.php?type=" . $_POST['type'] . '&amp;deleteAllOk=1');
+}
 
 if (isset($_POST['delete'])) {
 	// Show HTML Page
@@ -136,6 +137,7 @@ if (isset($_POST['delete'])) {
 	echo "<br>\n";
 	
 	// Delete dns
+	$allOk = true;
 	for ($m=0; $m<count($_SESSION['delete_dn']); $m++) {
 		// Set to true if an real error has happened
 		$stopprocessing = false;
@@ -149,7 +151,18 @@ if (isset($_POST['delete'])) {
 		// predelete actions
 		if (!$stopprocessing) {
 			foreach ($moduleNames as $singlemodule) {
-				$success = $modules[$singlemodule]->preDeleteActions();
+				$success = true;
+				$messages = $modules[$singlemodule]->preDeleteActions();
+				for ($i = 0; $i < sizeof($messages); $i++) {
+					$errors[] = $messages[$i];
+					if ($messages[$i][0] == 'ERROR') {
+						$success = false;
+						$allOk = false;
+					}
+					elseif ($messages[$i][0] == 'WARN') {
+						$allOk = false;
+					}
+				}
 				if (!$success) {
 					$stopprocessing = true;
 					break;
@@ -180,7 +193,10 @@ if (isset($_POST['delete'])) {
 				if (isset($attributes[$DNs[$i]]['errors'])) {
 					foreach ($attributes[$DNs[$i]]['errors'] as $singleerror) {
 						$errors[] = $singleerror;
-						if ($singleerror[0] == 'ERROR') $stopprocessing = true;
+						if ($singleerror[0] == 'ERROR') {
+							$stopprocessing = true;
+							$allOk = false;
+						}
 					}
 				}
 				if (!$stopprocessing) {
@@ -190,6 +206,7 @@ if (isset($_POST['delete'])) {
 						if (!$success) {
 							$errors[] = array ('ERROR', sprintf(_('Was unable to modify attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
 							$stopprocessing = true;
+							$allOk = false;
 						}
 					}
 					// add attributes
@@ -198,14 +215,16 @@ if (isset($_POST['delete'])) {
 						if (!$success) {
 							$errors[] = array ('ERROR', sprintf(_('Was unable to add attribtues to DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
 							$stopprocessing = true;
+							$allOk = false;
 						}
 					}
-					// removce attributes
+					// remove attributes
 					if (isset($attributes[$DNs[$i]]['remove']) && !$stopprocessing) {
 						$success = @ldap_mod_del($_SESSION['ldap']->server(), $DNs[$i], $attributes[$DNs[$i]]['remove']);
 						if (!$success) {
 							$errors[] = array ('ERROR', sprintf(_('Was unable to remove attribtues from DN: %s.'), $DNs[$i]), ldap_error($_SESSION['ldap']->server()));
 							$stopprocessing = true;
+							$allOk = false;
 						}
 					}
 				}
@@ -213,35 +232,53 @@ if (isset($_POST['delete'])) {
 		}
 		if (!$stopprocessing) {
 			$errors = deleteDN($_SESSION['delete_dn'][$m]);
-			if (sizeof($errors) > 0) $stopprocessing = true;
+			if (sizeof($errors) > 0) {
+				$stopprocessing = true;
+				$allOk = false;
+			}
 		}
 		// post delete actions
 		if (!$stopprocessing) {
 			foreach ($moduleNames as $singlemodule) {
-				$modules[$singlemodule]->postDeleteActions();
+				$messages = $modules[$singlemodule]->postDeleteActions();
+				for ($i = 0; $i < sizeof($messages); $i++) {
+					$errors[] = $messages[$i];
+					if (($messages[$i][0] == 'ERROR') || ($messages[$i][0] == 'WARN')) {
+						$allOk = false;
+					}
+				}
 			}
 		}		
 		if (!$stopprocessing) {
 			echo sprintf(_('Deleted DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
-			foreach ($errors as $error) StatusMessage($error[0], $error[1], $error[2]);
+			foreach ($errors as $error) {
+				call_user_func_array('StatusMessage', $error);
+			}
 			echo "<br>\n";
 			flush();
 		}
 		else {
 			echo sprintf(_('Error while deleting DN: %s'), $_SESSION['delete_dn'][$m]) . "<br>\n";
-			foreach ($errors as $error) StatusMessage($error[0], $error[1], $error[2]);
+			foreach ($errors as $error) {
+				call_user_func_array('StatusMessage', $error);
+			}
 			echo "<br>\n";
 		}
 	}
-	$_SESSION['cache']->refresh_cache(true);
 	echo "<br>\n";
 	echo "<br><button class=\"smallPadding\" name=\"cancel\" id=\"backButton\">" . _('Back to list') . "</button>\n";
+	echo "<br><button class=\"hidden\" name=\"cancelAllOk\" id=\"backButtonAllOk\"> </button>\n";
 	echo "</div>\n";
 	echo "</form>\n";
 	?>
 	<script type="text/javascript" language="javascript">
 	jQuery(document).ready(function() {
 		jQuery('#backButton').button();
+		<?php
+		if ($allOk) {
+			echo "jQuery('#backButtonAllOk').click();";
+		}
+		?>
 	});
 	</script>
 	<?php
