@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: login.php,v 1.141 2010/08/31 18:49:25 gruberroland Exp $
+$Id: login.php,v 1.143 2011/02/18 19:15:43 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2005 - 2010  Roland Gruber
+                2005 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ if(isset($_GET['useProfile'])) {
 $default_Config = new LAMCfgMain();
 $_SESSION["cfgMain"] = $default_Config;
 $default_Profile = $default_Config->default;
-if(isset($_COOKIE["lam_default_profile"])) {
+if(isset($_COOKIE["lam_default_profile"]) && in_array($_COOKIE["lam_default_profile"], getConfigProfiles())) {
 	$default_Profile = $_COOKIE["lam_default_profile"];
 }
 // Reload loginpage after a profile change
@@ -410,11 +410,11 @@ function display_LoginPage($config_object) {
 					<SMALL>
 					<?php
 						if (isLAMProVersion()) {
-							echo "LDAP Account Manager <b>Pro</b>: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+							echo "LDAP Account Manager Pro - " . LAMVersion() . "&nbsp;&nbsp;&nbsp;";
 							logNewMessage(LOG_DEBUG, "LAM Pro " . LAMVersion());
 						}
 						else {
-							echo "LDAP Account Manager: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+							echo "LDAP Account Manager - " . LAMVersion() . "&nbsp;&nbsp;&nbsp;";
 							logNewMessage(LOG_DEBUG, "LAM " . LAMVersion());
 						}
 					?>
