@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profiledelete.php,v 1.24 2010/05/26 18:40:59 gruberroland Exp $
+$Id: profiledelete.php,v 1.26 2010/10/16 17:52:08 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -52,7 +52,7 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 }
 
 // check if admin has submited delete operation
-if ($_POST['submit']) {
+if (isset($_POST['submit'])) {
 	// delete profile
 	if (!delAccountProfile($_POST['del'], $_POST['type'])) {
 		metaRefresh('profilemain.php?deleteScope=' . $_POST['type'] . '&amp;deleteFailed=' . $_POST['del']);
@@ -65,22 +65,38 @@ if ($_POST['submit']) {
 }
 
 // check if admin has aborted delete operation
-if ($_POST['abort']) {
+if (isset($_POST['abort'])) {
 	metaRefresh('profilemain.php');
 	exit;
 }
 
 // print standard header
 include '../main_header.php';
-echo ("<p><br></p>\n");
+echo "<div class=\"userlist-bright smallPaddingContent\">\n";
+echo "<form action=\"profiledelete.php\" method=\"post\">\n";
 
 $type = $_GET['type'];
-echo ("<p align=\"center\"><big>" . _("Do you really want to delete this profile?") . " <b>");
-echo ($_GET['del'] . "</b></big><br></p>\n");
-echo ("<form action=\"profiledelete.php\" method=\"post\">\n");
-echo ("<p align=\"center\">\n");
-echo ("<input type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n");
-echo ("<input type=\"submit\" name=\"abort\" value=\"" . _("Cancel") . "\">\n");
-echo ("<input type=\"hidden\" name=\"type\" value=\"$type\">");
-echo ("<input type=\"hidden\" name=\"del\" value=\"" . $_GET['del'] . "\">");
-echo ("</p></form></body></html>\n");
+
+$container = new htmlTable();
+$container->addElement(new htmlOutputText(_("Do you really want to delete this profile?")), true);
+$container->addElement(new htmlSpacer(null, '10px'), true);
+
+$subContainer = new htmlTable();
+$subContainer->addElement(new htmlOutputText(_("Profile name") . ': '));
+$subContainer->addElement(new htmlOutputText($_GET['del']), true);
+$container->addElement($subContainer, true);
+$container->addElement(new htmlSpacer(null, '10px'), true);
+
+$buttonContainer = new htmlTable();
+$buttonContainer->addElement(new htmlButton('submit', _("Ok")));
+$buttonContainer->addElement(new htmlButton('abort', _("Cancel")));
+$buttonContainer->addElement(new htmlHiddenInput('type', $type));
+$buttonContainer->addElement(new htmlHiddenInput('del', $_GET['del']));
+$container->addElement($buttonContainer);
+
+$tabindex = 1;
+parseHtml(null, $container, array(), false, $tabindex, 'user');
+
+echo "</form>\n";
+echo "</div>";
+include '../main_footer.php';
