@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.25 2010/10/17 13:38:32 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.26 2010/11/16 18:38:48 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2006 - 2010  Roland Gruber
@@ -169,6 +169,7 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText, $container) {
  */
 function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota, $container) {
 	$SPLIT_DELIMITER = "###x##y##x###";
+	$LAMDAEMON_PROTOCOL_VERSION = '1';
 	$okImage = "../../graphics/pass.png";
 	$failImage = "../../graphics/fail.png";
 	
@@ -260,6 +261,10 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota, $contai
 		$stopTest = lamTestLamdaemon("+" . $SPLIT_DELIMITER . "test" . $SPLIT_DELIMITER . "basic", $stopTest, $handle, _("Execute lamdaemon"), $container);
 	}
 	
+	if (!$stopTest) {
+		$stopTest = lamTestLamdaemon("+" . $SPLIT_DELIMITER . "test" . $SPLIT_DELIMITER . "version" . $SPLIT_DELIMITER . $LAMDAEMON_PROTOCOL_VERSION, $stopTest, $handle, _("Lamdaemon version"), $container);
+	}
+	
 	if (!$stopTest) {
 		$handle = lamTestConnectSSH($serverName);
 		@$handle->login($userName, $credentials[1]);
