@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: tools.php,v 1.17 2010/10/16 16:56:29 gruberroland Exp $
+$Id: tools.php,v 1.18 2010/12/19 13:37:15 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -60,7 +60,7 @@ echo "<div class=\"userlist-bright smallPaddingContent\">\n";
 
 // print tools table
 $container = new htmlTable();
-$container->addElement(new htmlSubTitle(_('Tools')), true);
+$container->addElement(new htmlTitle(_('Tools')), true);
 
 for ($i = 0; $i < sizeof($tools); $i++) {
 	// check access level
